package http

import (
	"net/http"

	"git.javil.eu/jacob1123/budgeteer"
	"git.javil.eu/jacob1123/budgeteer/postgres"
	"github.com/gin-gonic/gin"
	"github.com/google/uuid"
)

type BudgetData struct {
	AlwaysNeededData
	Transactions []postgres.GetTransactionsForBudgetRow
}

func (h *Handler) budget(c *gin.Context) {
	budgetID := c.Param("budgetid")
	budgetUUID, err := uuid.Parse(budgetID)
	if err != nil {
		c.Redirect(http.StatusTemporaryRedirect, "/login")
		return
	}

	transactions, err := h.Service.DB.GetTransactionsForBudget(c.Request.Context(), budgetUUID)
	if err != nil {
		c.AbortWithError(http.StatusInternalServerError, err)
		return
	}

	d := BudgetData{
		c.MustGet("data").(AlwaysNeededData),
		transactions,
	}

	c.HTML(http.StatusOK, "budget.html", d)
}

func (h *Handler) newBudget(c *gin.Context) {
	budgetName, succ := c.GetPostForm("name")
	if !succ {
		c.AbortWithStatus(http.StatusNotAcceptable)
		return
	}

	userID := c.MustGet("token").(budgeteer.Token).GetID()
	_, err := h.Service.NewBudget(c.Request.Context(), budgetName, userID)
	if err != nil {
		c.AbortWithError(http.StatusInternalServerError, err)
		return
	}
}
